@@ -28,10 +28,10 @@ bool has_mlock()
 /*
 * Lock an area of memory into RAM
 */
-bool lock_mem(void* ptr, u32bit bytes)
+bool lock_mem(void* ptr, size_t bytes)
    {
 #if defined(BOTAN_TARGET_OS_HAS_POSIX_MLOCK)
-   return (::mlock(ptr, bytes) == 0);
+   return (::mlock(static_cast<char*>(ptr), bytes) == 0);
 #elif defined(BOTAN_TARGET_OS_HAS_WIN32_VIRTUAL_LOCK)
    return (::VirtualLock(ptr, bytes) != 0);
 #else
@@ -42,10 +42,10 @@ bool lock_mem(void* ptr, u32bit bytes)
 /*
 * Unlock a previously locked region of memory
 */
-void unlock_mem(void* ptr, u32bit bytes)
+void unlock_mem(void* ptr, size_t bytes)
    {
 #if defined(BOTAN_TARGET_OS_HAS_POSIX_MLOCK)
-   ::munlock(ptr, bytes);
+   ::munlock(static_cast<char*>(ptr), bytes);
 #elif defined(BOTAN_TARGET_OS_HAS_WIN32_VIRTUAL_LOCK)
    ::VirtualUnlock(ptr, bytes);
 #endif
